@@ -11,6 +11,7 @@
 
 #include <QPainter>
 #include <QTime>
+#include <cmath>
 #include "ClockPartsDraw.h"
 #include "ThemeResource.h"
 #include "ThemeClockDraw.h"
@@ -45,8 +46,10 @@ namespace {
       pixmap->scaled(static_cast<int>(scaling_percent * size.width() / 100.0),
                      static_cast<int>(scaling_percent * size.height() / 100.0));
 
-    int offset_x = static_cast<int>(scaling_percent * offset.x() / 100.0);
-    int offset_y = static_cast<int>(scaling_percent * offset.y() / 100.0);
+    int offset_x =
+      static_cast<int>(round(scaling_percent * offset.x() / 100.0));
+    int offset_y =
+      static_cast<int>(round(scaling_percent * offset.y() / 100.0));
 
     if (center_position) {
       // 回転前の状態をスタックに積んでおく
@@ -138,12 +141,11 @@ namespace {
 
 
 // 再描画
-void ClockPartsDraw::redraw(ThemeClockDraw* parent,
+void ClockPartsDraw::redraw(QPainter& painter,
                             const ThemeResource& resource,
                             const QVector<QPoint>& digital_positions,
                             size_t scaling_percent, int sec_offset) {
 
-  QPainter painter(parent);
   painter.setRenderHint(QPainter::SmoothPixmapTransform);
 
   // ベース画像の描画
