@@ -13,7 +13,6 @@
 #include <QVector>
 
 class QPoint;
-class ThemeClockDraw;
 class ThemeResource;
 
 
@@ -24,7 +23,7 @@ namespace ClockPartsDraw {
 
     \brief parent [i] 親ウィジット
   */
-  extern void redraw(ThemeClockDraw* parent,
+  extern void redraw(QPainter& painter,
                      const ThemeResource& resource,
                      const QVector<QPoint>& digital_positions,
                      size_t scaling_percent = 100, int sec_offset = 0);
