@@ -46,7 +46,13 @@ private slots:
   void setScalingPercent(int value);
 
 signals:
-  void scalingValueChanged(int);
+
+  /*!
+    \brief 拡大率の変更
+
+    \param percent [o] 拡大率 [%]
+  */
+  void scalingValueChanged(int percent);
 };
 
 #endif /* !SETTING_DIALOG_FORM_H */
