@@ -43,7 +43,8 @@ class SettingConfig {
     \param tags [o] タグ情報の格納先
     \param data [i] XML データ配列
   */
-  explicit SettingConfig(QMap<QString, QString>& tags, QByteArray& data);
+  explicit SettingConfig(QMap<std::string, std::string>& tags,
+                         QByteArray& data);
   ~SettingConfig(void);
 
 
