@@ -18,6 +18,7 @@
 #include <QRegion>
 #include <QBitmap>
 #include <QCloseEvent>
+#include <QPainter>
 #include "ThemeClockDraw.h"
 #include "RrdaEncoder.h"
 #include "RrdaResource.h"
@@ -283,7 +284,8 @@ struct ThemeClockDraw::pImpl {
   void paintEvent(ThemeClockDraw* parent) {
 
     // 部品の再描画
-    ClockPartsDraw::redraw(parent, theme_resource_, digital_positions_,
+    QPainter painter(parent);
+    ClockPartsDraw::redraw(painter, theme_resource_, digital_positions_,
                            scaling_percent_, sec_offset_);
   }
 
