@@ -101,11 +101,10 @@ public:
   /*!
     \brief 描画の拡大率を設定
 
-    \param percernt [i] 描画の拡大率
+    \param percent [i] 描画の拡大率
   */
   void updateScalingPercent(size_t percent);
 
-
 signals:
   /*!
     \brief 終了シグナルを投げる
