@@ -46,7 +46,7 @@ struct ThemeClockWidget::pImpl {
   void initializeForm(ThemeClockWidget* parent) {
 
     // アイコンを適用
-    parent->setWindowIcon(QIcon(":icons/qclock_icon"));
+    parent->setWindowIcon(QIcon(":icons/qtmclock_icon"));
 
     // 時計の更新設定
     connect(&clock_timer_, SIGNAL(timeout()), parent, SLOT(redraw()));
@@ -55,9 +55,6 @@ struct ThemeClockWidget::pImpl {
     connect(&setting_dialog_, SIGNAL(scalingValueChanged(int)),
             parent, SLOT(changeScaling(int)));
 
-    // 終了処理
-    connect(draw_widget_, SIGNAL(quit()), parent, SLOT(close()));
-
     // テーマファイルの Drop を許可
     parent->setAcceptDrops(true);
   }
@@ -224,10 +221,6 @@ void ThemeClockWidget::resizeEvent(QResizeEvent* event) {
   if (region) {
     setMask(*region);
   }
-
-  // !!! または、表示自体の拡大率を変更してしまう？
-  // !!! いや、通常はウィンドウが出ないので、画像サイズの変更は無理
-  // !!! ドロップ用の処理を記述すべき
 }
 
 
