@@ -46,7 +46,7 @@ public:
 
 
   /*!
-    \brief リリースデータの登録 (暗号化)
+    \brief リリースデータの登録 (制限データ)
 
     \param tag [i] タグ
     \param file [i] データファイル名
