@@ -6,7 +6,7 @@
 
   $Id$
 
-  \todo ディレクトリ名を除去する関数を作成し、くくる
+  \todo 作りなおす機会があれば、ベース画像は特別扱いにしておく
 */
 
 #include <QHeaderView>
@@ -25,6 +25,7 @@
 #include "ConvertStdStringPath.h"
 #include "ThemeClockDraw.h"
 #include "ThemeResource.h"
+#include "PartsPlaceScene.h"
 
 using namespace qrk;
 
@@ -37,6 +38,8 @@ namespace {
   typedef QMap<std::string, QIcon*> Icons;
   typedef QMap<std::string, QGraphicsItem*> Items;
 
+  typedef QMap<std::string, QRect> AdditionalLinesRect;
+
   typedef QMap<std::string, QPoint> PositionMap;
 
   typedef struct {
@@ -93,8 +96,9 @@ struct ThemeConfigWindow::pImpl {
   Pixmaps pixmaps_;
   Icons icons_;
 
-  QGraphicsScene* scene_;
+  PartsPlaceScene* scene_;
   Items items_;
+  AdditionalLinesRect additional_lines_rect_;
   std::vector<QPixmap> digital_parts_;
 
   PositionMap parts_positions_;
@@ -106,6 +110,8 @@ struct ThemeConfigWindow::pImpl {
 
   QTimer redraw_timer_;
 
+  QCursor cursor_;
+
   pImpl(void)
     : new_act_(NULL), open_act_(NULL), save_act_(NULL),
       archive_config_(NULL), setting_config_(NULL), save_ok_(false),
@@ -151,6 +157,10 @@ struct ThemeConfigWindow::pImpl {
     (void) new QShortcut(Qt::Key_Up, parent, SLOT(upPressed()));
     (void) new QShortcut(Qt::Key_Down, parent, SLOT(downPressed()));
 
+    // クリックによる部品の選択
+    connect(scene_, SIGNAL(clicked(int, int)),
+            parent, SLOT(partsClickedHandler(int, int)));
+
     // 部品画像の更新
     connect(parent->image_lineedit_, SIGNAL(returnPressed()),
             parent, SLOT(partsEditHandler()));
@@ -177,14 +187,14 @@ struct ThemeConfigWindow::pImpl {
     // 時刻オフセット
     connect(parent->offset_slider_, SIGNAL(valueChanged(int)),
             parent, SLOT(offsetUpdated(int)));
-    // !!!
   }
 
 
   // 描画ウィンドウの更新
   void initializeGraphicsView(ThemeConfigWindow* parent) {
 
-    scene_ = new QGraphicsScene(parent);
+    scene_ = new PartsPlaceScene(parent);
+    scene_->setBackgroundBrush(QPixmap(":/images/background"));
     parent->parts_view_->setScene(scene_);
   }
 
@@ -438,15 +448,17 @@ struct ThemeConfigWindow::pImpl {
     for (size_t i = 0; i < n; ++i) {
       pixmaps_.insert(tag_names[i], &digital_parts_[i]);
     }
-
-    // 部品の座標位置が全て (0, 0) ならば、配置を初期化する
-    // !!!
   }
 
 
   // 描画アイテムの再構築
   void updateItems(void) {
 
+    if (! setting_config_) {
+      // 部品がロードされていなければ、戻る
+      return;
+    }
+
     // デジタル部品の位置が全て (0, 0) のときに、デフォルトの配置を行う
     if (isDigitalZeroPosition()) {
       updateDefaultDigitalPosition();
@@ -485,6 +497,41 @@ struct ThemeConfigWindow::pImpl {
     if (! setting_config_->getValue("analog/sec").compare("on")) {
       registerItem(parent, "analog/hari_s");
     }
+
+    // 補助線
+    QPen rect_pen;
+    rect_pen.setStyle(Qt::DashLine);
+
+    QPen line_pen;
+    line_pen.setStyle(Qt::DotLine);
+
+    for (AdditionalLinesRect::iterator it = additional_lines_rect_.begin();
+         it != additional_lines_rect_.end(); ++it) {
+
+      // 枠線を描画
+      std::string key = it.key();
+      QGraphicsItem* item_parent = items_[key];
+
+      QRect rect = it.value();
+      QGraphicsRectItem* rect_item =
+        new QGraphicsRectItem(0, 0, rect.width() - 1, rect.height() - 1,
+                              item_parent);
+      rect_item->setPen(rect_pen);
+
+      // 中心を通る直線を描画
+      if (! key.compare(0, 12, "analog/hari_")) {
+        int center_x = rect.width() / 2;
+        int center_y = rect.height() / 2;
+        QGraphicsLineItem* horizontal_line =
+          new QGraphicsLineItem(0, center_y, rect.width() - 1, center_y,
+                                item_parent);
+        horizontal_line->setPen(line_pen);
+        QGraphicsLineItem* vertical_line =
+          new QGraphicsLineItem(center_x, 0, center_x, rect.height() - 1,
+                                item_parent);
+        vertical_line->setPen(line_pen);
+      }
+    }
   }
 
 
@@ -530,6 +577,13 @@ struct ThemeConfigWindow::pImpl {
     };
     size_t n = sizeof(digital_tags) / sizeof(digital_tags[0]);
     for (size_t i = 0; i < n; ++i) {
+
+      PositionMap::iterator p = parts_positions_.find(digital_tags[i]);
+      if (p == parts_positions_.end()) {
+        // タグがなければ、戻る
+        return false;
+      }
+
       QPointF position = parts_positions_[digital_tags[i]];
       if ((fabs(position.x()) > 0.1) || (fabs(position.y()) > 0.1)) {
         return false;
@@ -839,6 +893,79 @@ struct ThemeConfigWindow::pImpl {
     int sec_offset = parent->offset_slider_->value() * 60;
     preview_draw_.redraw(sec_offset);
   }
+
+
+  // 補助線の追加
+  void drawAdditionalLine(const std::string& selected_tag) {
+
+    // ベース画像は対象外
+    if (! selected_tag.compare("base/base_org")) {
+      return;
+    }
+
+    // 関連部品についても描画を行う
+    if (! selected_tag.compare("analog")) {
+      drawAdditionalLine("analog/hari_h");
+      drawAdditionalLine("analog/hari_m");
+      drawAdditionalLine("analog/hari_s");
+    }
+    if (! selected_tag.compare("digital/parts")) {
+      drawAdditionalLine("digital/h1");
+      drawAdditionalLine("digital/m1");
+      drawAdditionalLine("digital/s1");
+      drawAdditionalLine("digital/cl");
+      drawAdditionalLine("digital/ap");
+    }
+    if (! selected_tag.compare("digital/h1")) {
+      drawAdditionalLine("digital/h2");
+    }
+    if (! selected_tag.compare("digital/m1")) {
+      drawAdditionalLine("digital/m2");
+    }
+    if (! selected_tag.compare("digital/s1")) {
+      drawAdditionalLine("digital/s2");
+    }
+
+    PositionMap::iterator it_position = parts_positions_.find(selected_tag);
+    if (it_position == parts_positions_.end()) {
+      return;
+    }
+
+    QPoint position = it_position.value();
+    QPixmap* pixmap = NULL;
+    if (! selected_tag.compare(0, 8, "digital/")) {
+      pixmap = pixmaps_["0"];
+    } else {
+      pixmap = pixmaps_[selected_tag];
+    }
+    QSize size = (pixmap) ? pixmap->size() : QSize(0, 0);
+
+    // 針の部品は中心座標を登録してあるのを、画像位置に変更
+    if (! selected_tag.compare(0, 12, "analog/hari_")) {
+      position.setX(position.x() - (size.width() / 2));
+      position.setY(position.y() - (size.height() / 2));
+    }
+
+    // 描画する枠線を登録
+    additional_lines_rect_.
+      insert(selected_tag,
+             (QRect(position.x(), position.y(), size.width(), size.height())));
+  }
+
+
+  // 補助線の削除
+  void removeAdditionalLine(void) {
+    additional_lines_rect_.clear();
+  }
+
+
+  // 選択を解除する
+  void clearItemSelection(ThemeConfigWindow* parent) {
+
+    parent->parts_tree_->setCurrentItem(NULL);
+    additional_lines_rect_.clear();
+    updateItems();
+  }
 };
 
 
@@ -1124,9 +1251,14 @@ void ThemeConfigWindow::imageUploadHandler(void) {
   }
   std::string tag = p.value();
 
-  // カーソルのイベントハンドラが、現在のタグに従って処理を行う
+  // カーソルのイベントハンドラが、現在のタグに従って処理を行えるように登録
   pimpl->current_tag_ = tag;
 
+  // 補助線の再描画
+  pimpl->removeAdditionalLine();
+  pimpl->drawAdditionalLine(pimpl->current_tag_);
+  pimpl->updateItems();
+
   size_t n = sizeof(ImageTags) / sizeof(ImageTags[0]);
   bool found = pimpl->findItemTag(ImageTags, n, pimpl->current_tag_);
   if (! found) {
@@ -1198,19 +1330,42 @@ void ThemeConfigWindow::previewCloseHandler(void) {
 }
 
 
-// 再生のオフセット時間を変更
-// !!!
+// クリックによる部品の選択処理
+void ThemeConfigWindow::partsClickedHandler(int x, int y) {
+
+  QGraphicsItem* clicked_item = pimpl->scene_->itemAt(x, y);
+  if (! clicked_item) {
+    // 背景がクリックされた場合は、選択をクリアする
+    pimpl->clearItemSelection(this);
+    return;
+  }
+
+  // クリックされた部品を検索し、その部品を選択する
+  std::string found_tag;
+  for (Items::iterator it = pimpl->items_.begin();
+       it != pimpl->items_.end(); ++it) {
+    if (it.value() == clicked_item) {
+      found_tag = it.key();
+      break;
+    }
+  }
+  if (found_tag.empty() || (! found_tag.compare("base/base_org"))) {
+    // 登録外のタグ、またはベース画像ならば、現在の選択を解除する
+    pimpl->clearItemSelection(this);
+    return;
+  }
+
+  // 指定された項目のツリーを開く
+  QTreeWidgetItem* tree_item = pimpl->name_to_item_.value(found_tag, NULL);
+  if (tree_item) {
+    parts_tree_->setCurrentItem(tree_item);
+  }
+}
 
 
-// !!! ドラッグ & ドロップで画像ファイルを選択できるようにする
+// !!! ドラッグ & ドロップで画像ファイルを変更できるようにする
 // !!! 画像でなければ、実際には登録しない
 // !!! slot
 
 
-// 選択中の部品移動を行う
-// !!! slot
-
-
-
-
 // !!! Qt Demo の 画像のパズルを参考に、部品配置を変更するあたりを実装する
