@@ -1,9 +1,10 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="1.1" language="ja_JP">
+<defaultcodec></defaultcodec>
 <context>
     <name>QLabel</name>
     <message>
-        <location filename="../qtmclock/ThemeClockDraw.cpp" line="54"/>
+        <location filename="../qtmclock/ThemeClockDraw.cpp" line="55"/>
         <source>Drop theme file in this form.</source>
         <translation>テーマファイルを、このフォームにドロップして下さい.</translation>
     </message>
@@ -96,7 +97,7 @@
     <message>
         <location filename="ThemeConfigWindowForm.ui" line="159"/>
         <source>Value</source>
-        <translation>値</translation>
+        <translation>画像</translation>
     </message>
     <message>
         <location filename="ThemeConfigWindowForm.ui" line="377"/>
@@ -104,7 +105,7 @@
         <translation>Ctrl+N</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="851"/>
+        <location filename="ThemeConfigWindow.cpp" line="849"/>
         <source>Create a new config file.</source>
         <translation>設定ファイルの新規作成.</translation>
     </message>
@@ -114,7 +115,7 @@
         <translation>Ctrl+O</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="855"/>
+        <location filename="ThemeConfigWindow.cpp" line="853"/>
         <source>Open an exist config file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
@@ -124,7 +125,7 @@
         <translation>Ctrl+S</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="859"/>
+        <location filename="ThemeConfigWindow.cpp" line="857"/>
         <source>Save the config file to disk.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
@@ -164,17 +165,17 @@
         <translation>ヘルプ (&amp;H)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="850"/>
+        <location filename="ThemeConfigWindow.cpp" line="848"/>
         <source>New</source>
         <translation>新規作成</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="854"/>
+        <location filename="ThemeConfigWindow.cpp" line="852"/>
         <source>Open</source>
         <translation>開く</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="858"/>
+        <location filename="ThemeConfigWindow.cpp" line="856"/>
         <source>Save</source>
         <translation>保存</translation>
     </message>
@@ -239,17 +240,17 @@
         <translation>デジタル文字の秒を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="933"/>
+        <location filename="ThemeConfigWindow.cpp" line="931"/>
         <source>Open archive list file.</source>
         <translation>設定ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="975"/>
+        <location filename="ThemeConfigWindow.cpp" line="973"/>
         <source>archive list (*.txt)</source>
         <translation>設定ファイル (*.txt)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="973"/>
+        <location filename="ThemeConfigWindow.cpp" line="971"/>
         <source>Save archive list file.</source>
         <translation>設定ファイルの保存.</translation>
     </message>
@@ -284,22 +285,22 @@
         <translation>秒針を表示する.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1181"/>
+        <location filename="ThemeConfigWindow.cpp" line="1179"/>
         <source>Open parts file.</source>
         <translation>部品ファイルを開く.</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1183"/>
+        <location filename="ThemeConfigWindow.cpp" line="1181"/>
         <source>parts file (*.png)</source>
         <translation>部品ファイル (*.png)</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1054"/>
+        <location filename="ThemeConfigWindow.cpp" line="1052"/>
         <source>About qtmclock_config</source>
         <translation>qtmclock_config について</translation>
     </message>
     <message>
-        <location filename="ThemeConfigWindow.cpp" line="1058"/>
+        <location filename="ThemeConfigWindow.cpp" line="1056"/>
         <source>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Theme making tool for Qtmclock.&lt;/p&gt;&lt;p&gt;Report bugs to &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</source>
         <translation>&lt;h2&gt;Qtmclock Config&lt;/h2&gt;&lt;p&gt;Qtmclock 用のテーマ作成ツール&lt;/p&gt;&lt;p&gt;バグの報告先 &amp;lt;satofumi@users.sourceforge.jp&amp;gt;&lt;/p&gt;</translation>
     </message>
